| FCSc_mean | R Documentation |
Compiles all tabular data from the individual metrics and generate the final results
FCSc_mean(taxon, fcsin, fcsex)
taxon |
A character object that defines the name of the species as listed in the occurrence dataset |
fcsin |
A data frame containing summary results from the fcsin function |
fcsex |
A data frame containing summary results from the fcsex function |
data_comb : a data frame which aggreates final result summaries
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining occurrences from example
data(CucurbitaData)
##Obtaining Raster_list
data(CucurbitaRasts)
##Obtaining protected areas raster
data(ProtectedAreas)
## ecoregion features
data(ecoregions)
# convert the dataset for function
taxon <- "Cucurbita_cordata"
sdm <- terra::unwrap(CucurbitaRasts)$cordata
occurrenceData <- CucurbitaData
protectedAreas <- terra::unwrap(ProtectedAreas)
ecoregions <- terra::vect(ecoregions)
# generate exsitu conservation summaries
srs_exsitu <- SRSex(taxon = taxon,
occurrenceData = CucurbitaData
)
gBuffer <- generateGBuffers(taxon = taxon,
occurrenceData = occurrenceData,
bufferDistM = 50000
)#'
grs_exsitu <- GRSex(taxon = taxon,
sdm = sdm,
gBuffer = gBuffer
)
ers_exsitu <- ERSex(taxon = taxon,
sdm = sdm,
occurrenceData = occurrenceData,
gBuffer = gBuffer,
ecoregions = ecoregions,
idColumn = "ECO_NAME"
)
#Running fcsex
fcs_exsitu <- FCSex(taxon = taxon,
srsex = srs_exsitu,
grsex = grs_exsitu,
ersex = ers_exsitu
)
# generate insitu conservation summaries
srs_insitu <- SRSin(taxon = taxon,
sdm = sdm,
occurrenceData = CucurbitaData,
protectedAreas = protectedAreas
)
grs_insitu <- GRSin(taxon = taxon,
sdm = sdm,
protectedAreas = protectedAreas
)
ers_insitu <- ERSin(taxon = taxon,
sdm = sdm,
occurrenceData = occurrenceData,
protectedAreas = protectedAreas,
ecoregions = ecoregions,
idColumn = "ECO_NAME"
)
#Running fcsin
fcs_insitu <- FCSin(taxon = taxon,
srsin = srs_insitu,
grsin = grs_insitu,
ersin = ers_insitu
)
fsc_combine <- FCSc_mean(taxon = taxon,
fcsin = fcs_insitu,
fcsex = fcs_exsitu)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.