| FCSex | R Documentation |
This function calculates the average of the three ex situ conservation metrics returning a final conservation score summary table. It also assigns conservation priority categories
FCSex(taxon, srsex, grsex, ersex)
taxon |
A character object that defines the name of the species as listed in the occurrence dataset |
srsex |
A dataframe contain the results from the srsex function |
grsex |
A dataframe contain the results from the grsex function |
ersex |
A dataframe contain the results from the ersex function |
out_df : a data frames of values summarizing the results of the function
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining occurrences from example
data(CucurbitaData)
##Obtaining Raster_list
data(CucurbitaRasts)
##Obtaining protected areas raster
data(ProtectedAreas)
## ecoregion features
data(ecoregions)
# convert the dataset for function
taxon <- "Cucurbita_cordata"
sdm <- terra::unwrap(CucurbitaRasts)$cordata
occurrenceData <- CucurbitaData
protectedAreas <- terra::unwrap(ProtectedAreas)
ecoregions <- terra::unwrap(ecoregions)
# generate exsitu conservation summaries
srs_exsitu <- SRSex(taxon = taxon,
occurrenceData = CucurbitaData
)
gBuffer <- generateGBuffers(taxon = taxon,
occurrenceData = occurrenceData,
bufferDistM = 50000
)#'
grs_exsitu <- GRSex(taxon = taxon,
sdm = sdm,
gBuffer = gBuffer
)
ers_exsitu <- ERSex(taxon = taxon,
sdm = sdm,
occurrenceData = occurrenceData,
gBuffer = gBuffer,
ecoregions = ecoregions,
idColumn = "ECO_NAME"
)
#Running fcsex
fcs_exsitu <- FCSex(taxon = taxon,
srsex = srs_exsitu,
grsex = grs_exsitu,
ersex = ers_exsitu)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.