FCSin: Final conservation score in situ

View source: R/FCSin.R

FCSinR Documentation

Final conservation score in situ

Description

This function calculates the average of the three in situ conservation metrics and assigns a priority category based on the results

Usage

FCSin(taxon, srsin, grsin, ersin)

Arguments

taxon

A character object that defines the name of the species as listed in the occurrence dataset

srsin

A dataframe contain the results from the srsin function

grsin

A dataframe contain the results from the grsin function

ersin

A dataframe contain the results from the ersin function

Value

out_df : a data frames of values summarizing the results of the function

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining occurrences from example
data(CucurbitaData)
##Obtaining Raster_list
data(CucurbitaRasts)
##Obtaining protected areas raster
data(ProtectedAreas)
## ecoregion features
data(ecoregions)

# convert the dataset for function
taxon <- "Cucurbita_cordata"
sdm <- terra::unwrap(CucurbitaRasts)$cordata
occurrenceData <- CucurbitaData
protectedAreas <- terra::unwrap(ProtectedAreas)
ecoregions <- terra::vect(ecoregions)

# generate insitu conservation summaries
srs_insitu <- SRSin(taxon = taxon,
                    sdm = sdm,
                    occurrenceData = occurrenceData,
                    protectedAreas = protectedAreas
                    )

grs_insitu <- GRSin(taxon = taxon,
                    sdm = sdm,
                    protectedAreas = protectedAreas
                    )

ers_insitu <- ERSin(taxon = taxon,
                    sdm = sdm,
                    occurrenceData = occurrenceData,
                    protectedAreas = protectedAreas,
                    ecoregions = ecoregions,
                    idColumn = "ECO_NAME"
                    )

#Running fcsin
FCSin <- FCSin(taxon = taxon,
                    srsin = srs_insitu,
                    grsin = grs_insitu,
                    ersin = ers_insitu
                    )




GapAnalysis documentation built on May 12, 2026, 5:07 p.m.