| ProtectedAreas | R Documentation |
This dataset is a raster version of the world protected areas dataset used in Khoury et al., (2019)
ProtectedAreas
terra rast object
https://www.protectedplanet.net/en
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.