SRSin: Sampling representativeness score in situ

View source: R/SRSin.R

SRSinR Documentation

Sampling representativeness score in situ

Description

The SRSin process calculates the proportion of all occurrences of a taxon falling within the distribution model that also fall within a protected area

Usage

SRSin(taxon, sdm, occurrenceData, protectedAreas)

Arguments

taxon

A character object that defines the name of the species as listed in the occurrence dataset

sdm

a terra rast object that

occurrenceData

a data frame of values containing columns for the taxon, latitude, longitude, and type

protectedAreas

A terra rast object the contian spatial location of protected areas.

Value

A list object containing 1. results : a data frames of values summarizing the results of the function 2. points : a terra vect object showing all the points present within protected areas 3. map : a leaflet object showing the spatial results of the function

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining occurrences from example
data(CucurbitaData)
##Obtaining Raster_list
data(CucurbitaRasts)
##Obtaining protected areas raster
data(ProtectedAreas)

# convert the dataset for function
taxon <- "Cucurbita_cordata"
sdm <- terra::unwrap(CucurbitaRasts)$cordata
occurrenceData <- CucurbitaData
protectedAreas <- terra::unwrap(ProtectedAreas)
#Running SRSin
srs_insitu <- SRSin(taxon = taxon,
                    sdm = sdm,
                    occurrenceData = occurrenceData,
                    protectedAreas = protectedAreas
                    )


GapAnalysis documentation built on May 12, 2026, 5:07 p.m.