checkEcoregion: Quality check of ecoregion dataset

View source: R/checkEcoregion.R

checkEcoregionR Documentation

Quality check of ecoregion dataset

Description

Checks the class, crs, if the idColumn is a unique ID,

Usage

checkEcoregion(ecoregion, sdm, idColumn)

Arguments

ecoregion

A terra vect object the contains spatial information on all ecoregions of interests

sdm

a terra rast object that represented the expected distribution of the species

idColumn

A character vector that notes what column within the ecoregions object should be used as a unique ID

Value

ecoregions : A terra vect object the contains spatial information on all ecoregions of interests

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining Raster_list


GapAnalysis documentation built on May 12, 2026, 5:07 p.m.