checkProtectedAreas: Quality check on protected areas dataset

View source: R/checkProtectedAreas.R

checkProtectedAreasR Documentation

Quality check on protected areas dataset

Description

Checks the class, values, crs, and cell size of the protected areas raster to ensure these elements match those required by gap analysis functions.

Usage

checkProtectedAreas(protectedAreas, sdm)

Arguments

protectedAreas

A terra rast object the contian spatial location of protected areas.

sdm

a terra rast object that represented the expected distribution of the species

Value

protectedAreas : a terra rast object representing protected areas

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples


##Obtaining Raster_list


GapAnalysis documentation built on May 12, 2026, 5:07 p.m.