checksdm: Quality check on sdm imagery

View source: R/checkRasters.R

checksdmR Documentation

Quality check on sdm imagery

Description

Evaluates the class, crs, and values are standardizes to what the following gap analysis functions are required.

Usage

checksdm(sdm)

Arguments

sdm

a terra rast object that represented the expected distribution of the species

Value

sdm : a terra rast object that is in the correct CRS

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining Raster_list

GapAnalysis documentation built on May 12, 2026, 5:07 p.m.