generateCounts: Generate initial counts of the occurrence data

View source: R/generateCounts.R

generateCountsR Documentation

Generate initial counts of the occurrence data

Description

Performs data cleaning to generate a summary of all input occurrence data. These values area used in the SRSex function.

Usage

generateCounts(taxon, occurrenceData)

Arguments

taxon

A character object that defines the name of the species as listed in the occurrence dataset

occurrenceData

a data frame of values containing columns for the taxon, latitude, longitude, and type

Value

countsData : a data frames of values summarizing the results of the function

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining occurrences from example
data(CucurbitaData)

# convert the dataset for function
taxon <- "Cucurbita_cordata"
occurrenceData <- CucurbitaData

#Running generateCounts
counts <- generateCounts(taxon = taxon,
                    occurrenceData = occurrenceData
                    )


GapAnalysis documentation built on May 12, 2026, 5:07 p.m.