generateGBuffers: Generate buffer of G type occurrences

View source: R/generateGBuffers.R

generateGBuffersR Documentation

Generate buffer of G type occurrences

Description

Produces a terra vect object representing the area around the G type occurrences

Usage

generateGBuffers(taxon, occurrenceData, bufferDistM)

Arguments

taxon

A character object that defines the name of the species as listed in the occurrence dataset

occurrenceData

a data frame of values containing columns for the taxon, latitude, longitude, and type

bufferDistM

Distance in meters. Used to set the size of the buffered objects.

Value

A list object containing 1. data : a terra vect object showing all the buffered areas around the G type occurrences 2. map : a leaflet object showing the spatial results of the function

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining occurrences from example
data(CucurbitaData)

# convert the dataset for function
taxon <- "Cucurbita_cordata"
occurrenceData <- CucurbitaData

#Running generateGBuffers
gBuffer <- generateGBuffers(taxon = taxon,
                    occurrenceData = occurrenceData,
                    bufferDistM = 50000
                    )




GapAnalysis documentation built on May 12, 2026, 5:07 p.m.