| getDatasets | R Documentation |
Ecoregions and protected area data base are stored on a harvard dataverse repository. This functions check to see if those datasets have been download and will download them if not present.
getDatasets(out_dir = tools::R_user_dir("GapAnalysis", which = "data"))
out_dir |
A character vector specifying the output directory to save download files. |
A message confirming the datasets were downloaded, along with saving the files to the package's data directory.
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.