ERSex: Ecological representativeness score ex situ

View source: R/ERSex.R

ERSexR Documentation

Ecological representativeness score ex situ

Description

The ERSex process provides an ecological measurement of the proportion of a species range that can be considered to be conserved in ex situ repositories. The ERSex calculates the proportion of terrestrial ecoregions (The Nature Conservancy Geospatial Conservation Atlas 2019) represented within the G buffered areas out of the total number of ecoregions occupied by the distribution model.

Usage

ERSex(taxon, sdm, occurrenceData, gBuffer, ecoregions, idColumn)

Arguments

taxon

A character object that defines the name of the species as listed in the occurrence dataset

sdm

a terra rast object that represented the expected distribution of the species

occurrenceData

a data frame of values containing columns for the taxon, latitude, longitude, and type

gBuffer

A terra vect which encompases a specific buffer distance around all G points

ecoregions

A terra vect object the contains spatial information on all ecoregions of interests

idColumn

A character vector that notes what column within the ecoregions object should be used as a unique ID

Value

A list object containing 1. results : a data frames of values summarizing the results of the function 2. ecogaps : a terra vect object showing the ecoregions with no area within the g buffer objects 3. map : a leaflet object showing the spatial results of the function

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information

Examples

##Obtaining occurrences from example
data(CucurbitaData)
##Obtaining Raster_list
data(CucurbitaRasts)
## ecoregion features
data(ecoregions)

# convert the dataset for function
taxon <- "Cucurbita_cordata"
sdm <- terra::unwrap(CucurbitaRasts)$cordata
ecoregions <- terra::vect(ecoregions)
#Running generateGBuffers
gBuffer <- generateGBuffers(taxon = taxon,
                    occurrenceData = CucurbitaData,
                    bufferDistM = 50000
                    )
#Running ERSex
ers_exsitu <- ERSex(taxon = taxon,
                    sdm = sdm,
                    occurrenceData = CucurbitaData,
                   gBuffer = gBuffer,
                   ecoregions = ecoregions,
                   idColumn = "ECO_NAME"
                   )



GapAnalysis documentation built on May 12, 2026, 5:07 p.m.