| SRSex | R Documentation |
The SRSex process provides a general indication of the completeness of ex situ conservation collections, calculating the ratio of germplasm accessions (G) available in ex situ repositories to reference (H) records for each taxon, making use of all compiled records, regardless of whether they include coordinates, with an ideal (i.e., comprehensive) conservation ratio of 1:1. In this and in the subsequent measurements, if no G or H records exist, taxa are automatically considered to be of high priority for further conservation action and assigned a value of 0. If there are more G than H records, SRSex is set to 100.
SRSex(taxon, occurrenceData)
taxon |
A character object that defines the name of the species as listed in the occurrence dataset |
occurrenceData |
a data frame of values containing columns for the taxon, latitude, longitude, and type |
out_df : a data frames of values summarizing the results of the function
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining occurrences from example
data(CucurbitaData)
# convert the dataset for function
taxon <- "Cucurbita_cordata"
#Running SRSex
srs_exsitu <- SRSex(taxon = taxon,
occurrenceData = CucurbitaData
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.