View source: R/checkEcoregion.R
| checkEcoregion | R Documentation |
Checks the class, crs, if the idColumn is a unique ID,
checkEcoregion(ecoregion, sdm, idColumn)
ecoregion |
A terra vect object the contains spatial information on all ecoregions of interests |
sdm |
a terra rast object that represented the expected distribution of the species |
idColumn |
A character vector that notes what column within the ecoregions object should be used as a unique ID |
ecoregions : A terra vect object the contains spatial information on all ecoregions of interests
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining Raster_list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.