View source: R/checkProtectedAreas.R
| checkProtectedAreas | R Documentation |
Checks the class, values, crs, and cell size of the protected areas raster to ensure these elements match those required by gap analysis functions.
checkProtectedAreas(protectedAreas, sdm)
protectedAreas |
A terra rast object the contian spatial location of protected areas. |
sdm |
a terra rast object that represented the expected distribution of the species |
protectedAreas : a terra rast object representing protected areas
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining Raster_list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.