| checksdm | R Documentation |
Evaluates the class, crs, and values are standardizes to what the following gap analysis functions are required.
checksdm(sdm)
sdm |
a terra rast object that represented the expected distribution of the species |
sdm : a terra rast object that is in the correct CRS
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining Raster_list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.