View source: R/generateCounts.R
| generateCounts | R Documentation |
Performs data cleaning to generate a summary of all input occurrence data. These values area used in the SRSex function.
generateCounts(taxon, occurrenceData)
taxon |
A character object that defines the name of the species as listed in the occurrence dataset |
occurrenceData |
a data frame of values containing columns for the taxon, latitude, longitude, and type |
countsData : a data frames of values summarizing the results of the function
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining occurrences from example
data(CucurbitaData)
# convert the dataset for function
taxon <- "Cucurbita_cordata"
occurrenceData <- CucurbitaData
#Running generateCounts
counts <- generateCounts(taxon = taxon,
occurrenceData = occurrenceData
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.