View source: R/generateGBuffers.R
| generateGBuffers | R Documentation |
Produces a terra vect object representing the area around the G type occurrences
generateGBuffers(taxon, occurrenceData, bufferDistM)
taxon |
A character object that defines the name of the species as listed in the occurrence dataset |
occurrenceData |
a data frame of values containing columns for the taxon, latitude, longitude, and type |
bufferDistM |
Distance in meters. Used to set the size of the buffered objects. |
A list object containing 1. data : a terra vect object showing all the buffered areas around the G type occurrences 2. map : a leaflet object showing the spatial results of the function
Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information
##Obtaining occurrences from example
data(CucurbitaData)
# convert the dataset for function
taxon <- "Cucurbita_cordata"
occurrenceData <- CucurbitaData
#Running generateGBuffers
gBuffer <- generateGBuffers(taxon = taxon,
occurrenceData = occurrenceData,
bufferDistM = 50000
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.