getDatasets: Download datasets from the harvard dataverse repo

View source: R/getDatasets.R

getDatasetsR Documentation

Download datasets from the harvard dataverse repo

Description

Ecoregions and protected area data base are stored on a harvard dataverse repository. This functions check to see if those datasets have been download and will download them if not present.

Usage

getDatasets()

Value

A message confirming the datasets were downloaded, along with saving the files to the package's data directory.

References

Khoury et al. (2019) Ecological Indicators 98:420-429. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ecolind.2018.11.016")} Carver et al. (2021) GapAnalysis: an R package to calculate conservation indicators using spatial information


GapAnalysis documentation built on May 12, 2026, 5:07 p.m.